@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "",
+    "(active)": "",
     "Also available in:": "Също достъпно в:",
     "Archive": "Архив",
     "Categories": "Категории",
@@ -19,6 +20,7 @@ MESSAGES = {
     "Posted:": "Публиковано:",
     "Posts about %s": "Публикации относно %s",
     "Posts for year %s": "Публикации за %s година",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Публикации за {month} {year}",
     "Previous post": "Предишна публикация",
     "Publication date": "",
@@ -27,8 +29,11 @@ MESSAGES = {
     "Read more": "Прочети още",
     "Skip to main content": "",
     "Source": "Source",
+    "Subcategories:": "",
     "Tags and Categories": "Тагове и Категории",
     "Tags": "Тагове",
+    "Write your page here.": "",
+    "Write your post here.": "",
     "old posts, page %d": "стари публикации, страница %d",
     "page %d": "страница %d",
 }
