@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "%d min zbývajících",
+    "(active)": "",
     "Also available in:": "Dostupné také v",
     "Archive": "Archiv",
     "Categories": "Kategorie",
@@ -19,16 +20,20 @@ MESSAGES = {
     "Posted:": "Zveřejněno:",
     "Posts about %s": "Příspěvky o %s",
     "Posts for year %s": "Příspěvky v roce %s",
+    "Posts for {month} {day}, {year}": "Příspěvky v {month} {day}, {year}",
     "Posts for {month} {year}": "Příspěvky v {month} {year}",
     "Previous post": "Předchozí příspěvek",
     "Publication date": "Datum zveřejnění",
     "RSS feed": "RSS zdroj",
     "Read in English": "Číst v češtině",
     "Read more": "Číst dál",
-    "Skip to main content": "",
+    "Skip to main content": "Přeskočit na hlavní obsah",
     "Source": "Zdroj",
+    "Subcategories:": "",
     "Tags and Categories": "Štítky a kategorie",
     "Tags": "Štítky",
+    "Write your page here.": "",
+    "Write your post here.": "",
     "old posts, page %d": "staré příspěvky, strana %d",
     "page %d": "strana %d",
 }
