@@ -2,7 +2,8 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "%d min remaining to read": "",
+    "%d min remaining to read": "%d min verbleiben zum Lesen",
+    "(active)": "",
     "Also available in:": "Auch verfügbar in:",
     "Archive": "Archiv",
     "Categories": "Kategorien",
@@ -19,15 +20,20 @@ MESSAGES = {
     "Posted:": "Veröffentlicht:",
     "Posts about %s": "Einträge über %s",
     "Posts for year %s": "Einträge aus dem Jahr %s",
+    "Posts for {month} {day}, {year}": "Einträge vom {day}. {month} {year}",
     "Posts for {month} {year}": "Einträge aus {month} {year}",
     "Previous post": "Vorheriger Eintrag",
     "Publication date": "Veröffentlichungsdatum",
     "RSS feed": "RSS-Feed",
     "Read in English": "Auf Deutsch lesen",
     "Read more": "Weiterlesen",
+    "Skip to main content": "Springe zum Hauptinhalt",
     "Source": "Source",
+    "Subcategories:": "Unterkategorien:",
     "Tags and Categories": "Tags und Kategorien",
     "Tags": "Tags",
-    "old posts, page %d": "Vorherige Einträge, Seite %d",
+    "Write your page here.": "",
+    "Write your post here.": "",
+    "old posts, page %d": "Ältere Einträge, Seite %d",
     "page %d": "Seite %d",
 }
