@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "",
+    "(active)": "",
     "Also available in:": "Saadaval ka:",
     "Archive": "Arhiiv",
     "Categories": "Kategooriad",
@@ -19,6 +20,7 @@ MESSAGES = {
     "Posted:": "Postitatud:",
     "Posts about %s": "Postitused %s kohta",
     "Posts for year %s": "Postitused aastast %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Postitused {year} aasta kuust {month} ",
     "Previous post": "Eelmine postitus",
     "Publication date": "",
@@ -27,8 +29,11 @@ MESSAGES = {
     "Read more": "Loe veel",
     "Skip to main content": "",
     "Source": "Lähtekood",
+    "Subcategories:": "",
     "Tags and Categories": "Sildid ja kategooriad",
     "Tags": "Märksõnad",
+    "Write your page here.": "",
+    "Write your post here.": "",
     "old posts, page %d": "vanade postituste, leht %d",
     "page %d": "leht %d",
 }
