@@ -2,7 +2,8 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "%d min remaining to read": "",
+    "%d min remaining to read": "%d دقیقه برای خواندن باقی مانده",
+    "(active)": "",
     "Also available in:": "همچنین قابل دسترس از:",
     "Archive": "آرشیو",
     "Categories": "دسته‌ها",
@@ -19,16 +20,20 @@ MESSAGES = {
     "Posted:": "ارسال شده:",
     "Posts about %s": "ارسال‌ها دربارهٔ %s",
     "Posts for year %s": "ارسال‌ها برای سال %s",
+    "Posts for {month} {day}, {year}": "ارسال برای {month} {day}. {year}",
     "Posts for {month} {year}": "ارسال برای {month} {year}",
     "Previous post": "ارسال پیشین",
     "Publication date": "تاریخ انتشار",
     "RSS feed": "خوراک",
     "Read in English": "به فارسی بخوانید",
     "Read more": "بیشتر بخوانید",
-    "Skip to main content": "",
+    "Skip to main content": "متن اصلی را نادیده بگیر",
     "Source": "منبع",
+    "Subcategories:": "",
     "Tags and Categories": "برچسب‌ها و دسته‌ها",
     "Tags": "برچسب‌ها",
+    "Write your page here.": "",
+    "Write your post here.": "",
     "old posts, page %d": "صفحهٔ ارسال‌های قدیمی %d",
     "page %d": "برگه %d",
 }
