@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "%d minuuttia lukuaikaa",
-    "(active)": "",
+    "(active)": "(aktiivinen)",
     "Also available in:": "Saatavilla myös:",
     "Archive": "Arkisto",
     "Categories": "Kategoriat",
@@ -22,14 +22,14 @@ MESSAGES = {
     "Posts for year %s": "Postauksia vuodelta %s",
     "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Postauksia ajalle {month} {year}",
-    "Previous post": "Vanhempia postauksia",
+    "Previous post": "Edellinen postaus",
     "Publication date": "Julkaisupäivämäärä",
-    "RSS feed": "RSS syöte",
+    "RSS feed": "RSS-syöte",
     "Read in English": "Lue suomeksi",
     "Read more": "Lue lisää",
     "Skip to main content": "Hyppää sisältöön",
     "Source": "Lähde",
-    "Subcategories:": "",
+    "Subcategories:": "Alakategoriat:",
     "Tags and Categories": "Tagit ja kategoriat",
     "Tags": "Tagit",
     "Write your page here.": "",
