@@ -2,38 +2,38 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "%d min remaining to read": "",
-    "(active)": "",
+    "%d min remaining to read": "%d min gjenstår å lese",
+    "(active)": "(aktiv)",
     "Also available in:": "Også tilgjengelig på:",
     "Archive": "Arkiv",
     "Categories": "Kategorier",
-    "Comments": "",
+    "Comments": "Kommentarer",
     "LANGUAGE": "norsk",
-    "Languages:": "",
+    "Languages:": "Språk:",
     "More posts about %s": "Flere innlegg om %s",
     "Newer posts": "Nyere innlegg",
     "Next post": "Neste innlegg",
-    "No posts found.": "",
-    "Nothing found.": "",
+    "No posts found.": "Fant ingen innlegg.",
+    "Nothing found.": "Fant ingenting.",
     "Older posts": "Eldre innlegg",
     "Original site": "Opprinnelig side",
     "Posted:": "Publisert:",
     "Posts about %s": "Innlegg om %s",
     "Posts for year %s": "Innlegg fra %s",
-    "Posts for {month} {day}, {year}": "",
+    "Posts for {month} {day}, {year}": "Innlegg fra {day}. {month} {year}",
     "Posts for {month} {year}": "Innlegg fra {month} {year}",
     "Previous post": "Forrige innlegg",
-    "Publication date": "",
-    "RSS feed": "",
+    "Publication date": "Publiseringsdato",
+    "RSS feed": "RSS-nyhetskanal",
     "Read in English": "Les på norsk",
     "Read more": "Les mer",
-    "Skip to main content": "",
+    "Skip to main content": "Hopp til hovedinnholdet",
     "Source": "Kilde",
-    "Subcategories:": "",
+    "Subcategories:": "Underkategorier:",
     "Tags and Categories": "Merker og kategorier",
     "Tags": "Merker",
-    "Write your page here.": "",
-    "Write your post here.": "",
+    "Write your page here.": "Skriv siden din her.",
+    "Write your post here.": "Skriv innlegget din her.",
     "old posts, page %d": "eldre innlegg, side %d",
     "page %d": "side %d",
 }
