@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "zostało %d minut czytania",
+    "(active)": "(aktywne)",
     "Also available in:": "Również dostępny w językach:",
     "Archive": "Archiwum",
     "Categories": "Kategorie",
@@ -19,6 +20,7 @@ MESSAGES = {
     "Posted:": "Opublikowano:",
     "Posts about %s": "Posty o %s",
     "Posts for year %s": "Posty z roku %s",
+    "Posts for {month} {day}, {year}": "Posty z {day} {month} {year}",
     "Posts for {month} {year}": "Posty z {month} {year}",
     "Previous post": "Poprzedni post",
     "Publication date": "Data publikacji",
@@ -27,8 +29,11 @@ MESSAGES = {
     "Read more": "Czytaj więcej",
     "Skip to main content": "Przejdź do treści",
     "Source": "Źródło",
+    "Subcategories:": "Podkategorie:",
     "Tags and Categories": "Tagi i Kategorie",
     "Tags": "Tagi",
+    "Write your page here.": "Tu wpisz treść strony.",
+    "Write your post here.": "Tu wpisz treść postu.",
     "old posts, page %d": "stare posty, strona %d",
     "page %d": "strona %d",
 }
