@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "%d mín restante para leitura",
+    "(active)": "",
     "Also available in:": "Também disponível em:",
     "Archive": "Arquivo",
     "Categories": "Categorias",
@@ -19,16 +20,20 @@ MESSAGES = {
     "Posted:": "Publicado:",
     "Posts about %s": "Posts sobre %s",
     "Posts for year %s": "Posts do ano %s",
+    "Posts for {month} {day}, {year}": "Posts do {day} {month}, {year}",
     "Posts for {month} {year}": "Posts de {month} {year}",
     "Previous post": "Post anterior",
     "Publication date": "Data de publicação",
     "RSS feed": "Feed RSS",
     "Read in English": "Ler em português",
     "Read more": "Leia mais",
-    "Skip to main content": "",
+    "Skip to main content": "Pular para o conteúdo principal",
     "Source": "Código",
+    "Subcategories:": "",
     "Tags and Categories": "Tags e Categorias",
     "Tags": "Tags",
+    "Write your page here.": "",
+    "Write your post here.": "",
     "old posts, page %d": "Posts antigos, página %d",
     "page %d": "página %d",
 }
