@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "%d минут чтения осталось",
+    "(active)": "",
     "Also available in:": "Также доступно на:",
     "Archive": "Архив",
     "Categories": "Категории",
@@ -19,16 +20,20 @@ MESSAGES = {
     "Posted:": "Опубликовано:",
     "Posts about %s": "Записи о %s",
     "Posts for year %s": "Записи за %s год",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Записи за {month} {year}",
     "Previous post": "Предыдущая запись",
     "Publication date": "Дата опубликования",
     "RSS feed": "RSS лента",
     "Read in English": "Прочесть по-русски",
     "Read more": "Читать далее",
-    "Skip to main content": "",
+    "Skip to main content": "Перейти к главному содержимому",
     "Source": "Источник",
+    "Subcategories:": "",
     "Tags and Categories": "Тэги и категории",
     "Tags": "Тэги",
+    "Write your page here.": "",
+    "Write your post here.": "",
     "old posts, page %d": "%d страница со старыми записями",
     "page %d": "%d страница",
 }
