@@ -3,37 +3,37 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "%d min remaining to read": "%d minuter kvar att läsa",
-    "(active)": "",
+    "(active)": "(aktiv)",
     "Also available in:": "Även tillgänglig på:",
     "Archive": "Arkiv",
     "Categories": "Kategorier",
     "Comments": "Kommentarer",
     "LANGUAGE": "Svenska",
     "Languages:": "Språk:",
-    "More posts about %s": "Mer inlägg om %s",
+    "More posts about %s": "Fler inlägg om %s",
     "Newer posts": "Nya inlägg",
     "Next post": "Nästa inlägg",
-    "No posts found.": "Inga inlägg hittade",
-    "Nothing found.": "Inget hittat",
+    "No posts found.": "Inga inlägg hittade.",
+    "Nothing found.": "Inget hittat.",
     "Older posts": "Äldre inlägg",
-    "Original site": "Orgnialsida",
-    "Posted:": "Publicerad",
+    "Original site": "Originalsida",
+    "Posted:": "Publicerad:",
     "Posts about %s": "Inlägg om %s",
     "Posts for year %s": "Inlägg för år %s",
     "Posts for {month} {day}, {year}": "Inlägg för {month} {day}, {year}",
     "Posts for {month} {year}": "Inlägg för {month} {year}",
     "Previous post": "Föregående inlägg",
     "Publication date": "Publiceringsdatum",
-    "RSS feed": "RSS flöde",
-    "Read in English": "Läs på Svenska",
+    "RSS feed": "RSS-flöde",
+    "Read in English": "Läs på svenska",
     "Read more": "Läs mer",
-    "Skip to main content": "hoppa till huvudinehåll",
+    "Skip to main content": "Hoppa till huvudinnehåll",
     "Source": "Källa",
     "Subcategories:": "Underkategorier:",
     "Tags and Categories": "Taggar och Kategorier",
     "Tags": "Taggar",
-    "Write your page here.": "",
-    "Write your post here.": "",
+    "Write your page here.": "Skriv din sida här.",
+    "Write your post here.": "Skriv ditt inlägg här.",
     "old posts, page %d": "gamla inlägg, sida %d",
     "page %d": "sida %d",
 }
