@@ -2,7 +2,8 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "%d min remaining to read": "",
+    "%d min remaining to read": "%d dakikalık okuma",
+    "(active)": "",
     "Also available in:": "Şu dilde de mevcut:",
     "Archive": "Arşiv",
     "Categories": "Kategoriler",
@@ -19,16 +20,20 @@ MESSAGES = {
     "Posted:": "Yayın tarihi:",
     "Posts about %s": "%s ile ilgili yazılar",
     "Posts for year %s": "%s yılındaki yazılar",
+    "Posts for {month} {day}, {year}": "{month} {day}, {year} 'den beri olan yazılar",
     "Posts for {month} {year}": "{month} {year} göre yazılar",
     "Previous post": "Önceki yazı",
     "Publication date": "Yayınlanma tarihi",
     "RSS feed": "RSS kaynağı",
     "Read in English": "Türkçe olarak oku",
     "Read more": "Devamını oku",
-    "Skip to main content": "",
+    "Skip to main content": "Ana içeriğe geç",
     "Source": "Kaynak",
+    "Subcategories:": "",
     "Tags and Categories": "Etiketler ve Kategoriler",
     "Tags": "Etiketler",
+    "Write your page here.": "",
+    "Write your post here.": "",
     "old posts, page %d": "eski yazılar, sayfa %d",
     "page %d": "sayfa %d",
 }
