@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -24,6 +24,8 @@
 # OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+"""Slides directive for reStructuredText."""
+
 from __future__ import unicode_literals
 
 import uuid
@@ -36,9 +38,12 @@ from nikola.plugin_categories import RestExtension
 
 class Plugin(RestExtension):
 
+    """Plugin for reST slides directive."""
+
     name = "rest_slides"
 
     def set_site(self, site):
+        """Set Nikola site."""
         self.site = site
         directives.register_directive('slides', Slides)
         Slides.site = site
@@ -46,11 +51,14 @@ class Plugin(RestExtension):
 
 
 class Slides(Directive):
-    """ Restructured text extension for inserting slideshows."""
+
+    """reST extension for inserting slideshows."""
+
     has_content = True
 
     def run(self):
-        if len(self.content) == 0:
+        """Run the slides directive."""
+        if len(self.content) == 0:  # pragma: no cover
             return
 
         if self.site.invariant:  # for testing purposes
